@@ -5,7 +5,6 @@ from ..utils import BASE_URL
 
 
 def get_auth_link(
-    public_key,
     secret_key,
     sub_org_id,
     integration_name,
@@ -23,7 +22,6 @@ def get_auth_link(
 
     headers = {
         "secret": secret_key,
-        "id": public_key,
     }
     url = f"{BASE_URL}/api/{version}/sub-org/auth-link?sub_org_id={sub_org_id}&integration_name={integration_name}&redirect_uri={redirect_uri}"
 
