@@ -5,9 +5,9 @@ import os
 
 load_dotenv()
 
-PONGO_PUBLIC = os.getenv("PONGO_PUBLIC")
-PONGO_SECRET = os.getenv("PONGO_SECRET")
-pongo_client = pongo.PongoClient(PONGO_PUBLIC, PONGO_SECRET)
+
+PONGO_SECRET = os.getenv("PONGO_KEY")
+pongo_client = pongo.PongoClient(PONGO_SECRET)
 
 
 class TestWebScrape(unittest.TestCase):
@@ -22,7 +22,5 @@ class TestWebScrape(unittest.TestCase):
         assert res.status_code == 200
 
 
-
-
 if __name__ == "__main__":
     unittest.main()
